@@ -368,14 +368,18 @@ device_store_transaction (MbimDevice       *self,
 
     ctx = g_task_get_task_data (task);
 
-    ctx->wait_ctx = g_slice_new (TransactionWaitContext);
-    ctx->wait_ctx->self = self;
-     /* valid as long as the transaction is in the HT */
-    ctx->wait_ctx->transaction_id = ctx->transaction_id;
-    ctx->wait_ctx->type = type;
+    /* When storing the transaction in the device, we have two options: either this
+     * is a completely new transaction, or this is a transaction that had already been
+     * previously stored (e.g. when waiting for more fragments). In the latter case,
+     * make sure we don't reset the wait context or the timeout. */
 
-    /* don't add timeout if one already exists */
+    /* don't add timeout and setup wait context if one already exists */
     if (!ctx->timeout_source) {
+        g_assert (!ctx->wait_ctx);
+        ctx->wait_ctx = g_slice_new (TransactionWaitContext);
+        ctx->wait_ctx->self = self;
+        ctx->wait_ctx->transaction_id = ctx->transaction_id;
+        ctx->wait_ctx->type = type;
         ctx->timeout_source = g_timeout_source_new (timeout_ms);
         g_source_set_callback (ctx->timeout_source, (GSourceFunc)transaction_timed_out, ctx->wait_ctx, NULL);
         g_source_attach (ctx->timeout_source, g_main_context_get_thread_default ());
@@ -1377,6 +1381,7 @@ open_message_ready (MbimDevice   *self,
     if (!response) {
         /* If we get reported that the state is unknown, try to close before open */
         if (g_error_matches (error, MBIM_CORE_ERROR, MBIM_CORE_ERROR_UNKNOWN_STATE)) {
+            g_clear_error (&error);
             ctx->close_before_open = TRUE;
             ctx->step = DEVICE_OPEN_CONTEXT_STEP_CLOSE_MESSAGE;
             device_open_context_step (task);
@@ -1385,7 +1390,7 @@ open_message_ready (MbimDevice   *self,
 
         /* Check if we should be retrying after a timeout */
         if (g_error_matches (error, MBIM_CORE_ERROR, MBIM_CORE_ERROR_TIMEOUT)) {
-            /* Retry same step */
+            g_clear_error (&error);
             device_open_context_step (task);
             return;
         }
